/***********************************************************************************************************************************
Remote Command
***********************************************************************************************************************************/
#ifndef COMMAND_REMOTE_REMOTE_H
#define COMMAND_REMOTE_REMOTE_H

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
// Remote command
void cmdRemote(int fdRead, int fdWrite);

#endif
